/**
 * @file uartBluetooth.h
 * @brief UART Bluetooth Module header
 *
 * Proyecto Smart Watch - UART Bluetooth
 * UART Bluetooth module
 *
 * This module is used to configure the
 * UART peripheral of the MSP432P401R used for the HC-06 module. It will be used to send and receive data
 * using EUSCI_A2.
 *
 * uartBluetooth.h
 * Modules that allows the configuration of the UART peripheral of the MSP432P401R for the HC-06
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 23, 2021
 */

#ifndef INCLUDE_UARTBLUETOOTH_H_
#define INCLUDE_UARTBLUETOOTH_H_

/**
 * @brief Initializes UART module
 */
void initializeUARTBluetooth(void);

/**
 * @brief Sets callback function to be added from this module to the function queue
 * @param void* callback_function: function to be called when a new message is available
 *
 */
void setUartBluetoothCallbackFunction(void *callback_function);

/**
 * @brief Sends a char array using UART Bluetooth module
 * @param char* buffer_pointer: auxiliary buffer pointer which contains data to be transmitted
 *
 */
void uartBluetoothTransmit(char* buffer_pointer);

/**
 * @brief Copies message received by the UART module into an external char array indicated by buffer_pointer
 * @param char* buffer_pointer: auxiliary buffer pointer which points to the address to use for copying the message
 *
 */
void uartBluetoothReceive(char* buffer_pointer);

#endif /* INCLUDE_UARTBLUETOOTH_H_ */
