#include "msp.h"
#include "communications.h"
#include "common.h"
#include "user_interface.h"
#include "body_temperature.h"
#include "uart.h"
#include "uartBluetooth.h"

static char rx_buffer_uart[MESSAGE_DIMENSION];
static char tx_buffer_uart[MESSAGE_DIMENSION];

static char rx_buffer_bluetooth[MESSAGE_DIMENSION];
static char tx_buffer_bluetooth[MESSAGE_DIMENSION];

void processUARTIncomingPacket(void);
void processBluetoothIncomingPacket(void);
void bluetoothModuleConfiguration(void);
void cleanTXBuffer(char *buffer);

void initializeCommunications(void)
{
    initializeUART();
    setUartCallbackFunction(processUARTIncomingPacket);

    initializeUARTBluetooth();
    setUartBluetoothCallbackFunction(processBluetoothIncomingPacket);

    if(BLUETOOTH_CONFIGURED == 1)
    {
        P4OUT &= ~BIT0;
        //P4OUT |= BIT0;
    }
    else
    {
        P4OUT |= BIT0;
        //P4OUT &= ~BIT0;
        //AT Command Configuration - has to be run only once
        bluetoothModuleConfiguration();
    }
}

void sendPacket(void)
{
    tx_buffer_uart[0] = 0xFF;
    tx_buffer_uart[1] = 3;
    tx_buffer_uart[2] = (char)getLastTemperatureReading();

    tx_buffer_uart[3] = tx_buffer_uart[0] ^ tx_buffer_uart[1] ^ tx_buffer_uart[2];
    tx_buffer_uart[4] = '\r';

    /*tx_buffer_uart[0] = 'H';
    tx_buffer_uart[1] = 'o';
    tx_buffer_uart[2] = 'l';
    tx_buffer_uart[3] = 'a';
    tx_buffer_uart[4] = '\r';
    */

    if(BLUETOOTH_CONFIGURED == 1)
    {
        //uartTransmit(&tx_buffer_uart[0]);
    }
}

void processUARTIncomingPacket(void)
{
    turnOnDebugLED();
}

void bluetoothModuleConfiguration(void)
{
    /*tx_buffer_bluetooth[0] = 'A';
    tx_buffer_bluetooth[1] = 'T';
    tx_buffer_bluetooth[2] = '+';
    tx_buffer_bluetooth[3] = 'N';
    tx_buffer_bluetooth[4] = 'A';
    tx_buffer_bluetooth[5] = 'M';
    tx_buffer_bluetooth[6] = 'E';
    tx_buffer_bluetooth[7] = '\n';
    tx_buffer_bluetooth[8] = '\r';
    */

    tx_buffer_bluetooth[0] = 'A';
    tx_buffer_bluetooth[1] = 'T';
    tx_buffer_bluetooth[2] = '+';
    tx_buffer_bluetooth[3] = 'V';
    tx_buffer_bluetooth[4] = 'E';
    tx_buffer_bluetooth[5] = 'R';
    tx_buffer_bluetooth[6] = 'S';
    tx_buffer_bluetooth[7] = 'I';
    tx_buffer_bluetooth[8] = 'O';
    tx_buffer_bluetooth[9] = 'N';
    tx_buffer_bluetooth[10] = '\r';
    tx_buffer_bluetooth[11] = '\n';




    uartBluetoothTransmit(&tx_buffer_bluetooth[0]);
}

void processBluetoothIncomingPacket(void)
{
    uartBluetoothReceive(&rx_buffer_bluetooth[0]);
    //cleanTXBuffer(&tx_buffer_uart[0]);
    //tx_buffer_uart[3] = '\r';
    uartTransmit(&rx_buffer_bluetooth[0]);
}

void cleanTXBuffer(char *buffer)
{
    int i;
    for (i = 0; i<MESSAGE_DIMENSION; i++)
    {
        buffer[i] = 0;
    }
}
